import * as api from './api'
import {CreateCrudOptionsProps, CreateCrudOptionsRet, UserPageQuery} from '@fast-crud/fast-crud'
import {inject} from 'vue'
import {BaseColumn} from '/@/views/adManage/utils/commonTabColumn.js'
import {parseQueryParams} from '/@/views/adManage/utils/tools.js'
import XEUtils from 'xe-utils'

export const createCrudOptions = function ({ crudExpose, context }: CreateCrudOptionsProps): CreateCrudOptionsRet {
  const pageRequest = async (query: UserPageQuery) => {
    const params = parseQueryParams(context.value)
    XEUtils.assign(query, params)
    return await api.GetList(query)
  }

  //权限判定
  const hasPermissions = inject('$hasPermissions')

  return {
    crudOptions: {
      table: {
        height: 750,
        headerCellStyle: {
          backgroundColor: '#f6f7fa', // 直接设置背景颜色
          height: '20px',
          // border: '0.5px solid #ddd',
        },
        cellStyle: {
          border: 'none',
          borderBottom: '0.5px solid #ddd',
        },
      },
      container: {
        fixedHeight: false,
      },
      actionbar: {
        show: true,
        color: "#626aef",
        buttons: {
          add: {
            show: false
          },
          create: {
            text: '添加关键词',
            // type: 'primary',
            color: "#626aef",
            plain: true,
            show: true,
            click() {

            }
          },
        }
      },
      search: {
        show: true,
        buttons: {
					search: {
						show: false
					},
					reset: {
						show: false
					}
				}
      },
      // toolbar: {
      //   buttons: {
      //     search: {
      //       show: true,
      //     },
      //     compact: {
      //       show: false,
      //     },
      //   },
      // },
      request: {
        pageRequest,
      },
      rowHandle: {
        show: false,
      },
      columns: {
        keywordText: {
          title: '关键词',
          column: {
            width: '200px',
            fixed: 'left',
            align: 'center',
          },
        },
        state: {
          title: '状态',
          column: {
            width: '100px',
            align: 'center',
          },
        },
        suggestedBid: {
          title: '建议竞价',
          column: {
            width: '100px',
            align: 'center',
          },
        },
        bid: {
          title: '出价',
          column: {
            width: '60px',
            align: 'center',
          },
        },
        // currentBid: {
        //   title: '当前竞价',
        //   column: {
        //     width: '100px',
        //     align: 'center',
        //   },
        // },
        ...BaseColumn,
      },
    },
  }
}
