import * as api from './api'
import { dict, UserPageQuery, AddReq, DelReq, EditReq, compute, CreateCrudOptionsProps, CreateCrudOptionsRet } from '@fast-crud/fast-crud'
import { inject } from 'vue'
import { parseQueryParams } from '/@/views/adManage/utils/tools.js'
import XEUtils from 'xe-utils'
import { BaseColumn } from '/@/views/adManage/utils/commonTabColumn.js'
import { useRoute } from 'vue-router'


export const createCrudOptions = function ({ crudExpose, context }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const route = useRoute()
	const pageRequest = async (query: UserPageQuery) => {
		const params = parseQueryParams(context.value)
		XEUtils.assign(query, params)
    // query["adGroupId"] = route.query.adGroupId
		return await api.GetList(query)
	};
	const editRequest = async ({ form, row }: EditReq) => {
		form.id = row.id;
		return await api.UpdateObj(form);
	};
	const delRequest = async ({ row }: DelReq) => {
		return await api.DelObj(row.id);
	};
	const addRequest = async ({ form }: AddReq) => {
		return await api.AddObj(form);
	};

	//权限判定
	const hasPermissions = inject('$hasPermissions');

	return {
		crudOptions: {
			table: {
				height: 750,
				headerCellStyle: {
					backgroundColor: '#f6f7fa', // 直接设置背景颜色
					height: '20px',
					// border: '0.5px solid #ddd',
				},
				cellStyle: {
					border: 'none',
					borderBottom: '0.5px solid #ddd',
				},
			},
			container: {
        fixedHeight: false
      },
			actionbar: {
				show: true,
				color: "#626aef",
				buttons: {
					add: {
						show: false
					},
					create: {
						text: '添加广告',
						// type: 'primary',
						color: "#626aef",
						plain: true,
						show: true,
						click() {

						}
					},
				}
			},
			search: {
				show: true,
				buttons: {
					search: {
						show: false
					},
					reset: {
						show: false
					}
				}
			},
			toolbar: {
        buttons: {
					search: {
						show: true
					},
					compact: {
						show: false
					}
				}
			},
			request: {
				pageRequest,
				addRequest,
				editRequest,
				delRequest,
			},
			rowHandle: {
				fixed: 'right',
				width: 80,
				buttons: {
					view: {
						show: false,
					},
					edit: {
						iconRight: 'Edit',
						type: 'text',
            text: null
						// show: hasPermissions('dictionary:Update'),
					},
					remove: {
						iconRight: 'Delete',
						type: 'text',
            text: null
						// show: hasPermissions('dictionary:Delete'),
					},
				},
			},
			columns: {
        adGroupName: {
					title: '广告组名称',
					column: {
						width: 230,
						fixed: 'left',
					}
				},
				state: {
					title: '状态',
					column: {
						width: "100px"
					}
				},
				...BaseColumn
			}
		}
	}
}
